%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% min_beta_ocrd.m
%
% OCRD_1.0 - One Class Rate Distortion based algorithm, Version 1.0
% Copyright (C) 2007 Koby Crammer, Partha Talukdar and Fernando Pereira
%
% See: 
%   A Rate-Distortion One-Class Model and its Applications to Clustering
%   Koby Crammer, Partha Pratim Talukdar and Fernando Pereira
%   Proceedings of the 25th International Conference on Machine Learning
%   (ICML), 2008 
%   http://www.cis.upenn.edu/~crammer/publications/icml08_ocrd.pdf
%
%    This program is free software; you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation; either version 2 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program; if not, write to the Free Software
%    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function [mnbeta, mxbeta] = min_beta_ocrd(px, x, bregman_fn)
%
% function [mnbeta, mxbeta] = min_beta_ocrd(px, x, bregman_fn)
%   seeks for min and max values of beta for the OCRD algorithm
%   px - prior weights
%   x  - data, column vector
%   bregman_fn - bregman function to be used
%   mnbeta, mxbeta - min and max values to be used
    
q = ones(size(px));
q_1 = sum(q .* px);
 
w = (q .* px)/q_1;
mn = compute_mean(x, w);
adiv = compute_dist(x, mn, bregman_fn);
tmp = -log(px)./ adiv;
mnbeta = min (tmp);
mxbeta = max (tmp);
