
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% run_toy_data.m
%
% OCRD_1.0 - One Class Rate Distortion based algorithm, Version 1.0
% Copyright (C) 2007 Koby Crammer, Partha Talukdar and Fernando Pereira
%
% See: 
%   A Rate-Distortion One-Class Model and its Applications to Clustering
%   Koby Crammer, Partha Pratim Talukdar and Fernando Pereira
%   Proceedings of the 25th International Conference on Machine Learning
%   (ICML), 2008 
%   http://www.cis.upenn.edu/~crammer/publications/icml08_ocrd.pdf
%
%    This program is free software; you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation; either version 2 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program; if not, write to the Free Software
%    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% demostrates the OC algorithm for finding one-cluster using RD theory
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Init 
seed=1;rand('state',seed);
seed=1;randn('state',seed);
MS = 'Markersize';
LW = 'LineWidth';

orig = [0.9 0.5];

% Create data 
n_samples = 1000;
n_in_clust = floor(n_samples*0.30);
n_out_clust = n_samples- n_in_clust;
x = [rand(n_out_clust,1);randn(n_in_clust,1)/20+orig(1)];
y = [rand(n_out_clust,1);randn(n_in_clust,1)/20+orig(2)];
data = [x,y]';

% plot data
figure(1),clf;hold on;
plot(x,y,'k.');
axis([ 0 1 0 1 ])
plot(orig(1),orig(2),'bo','LineWidth',5,MS,20);
drawnow

N = size(data,2);

% compute range of betas
data_s.data = data;
params_s.bregman_fn.f = @bregman_l2;
params_s.bregman_fn.params_s.dummy = [];
data_s.pdata = ones(N,1)/N;
[mnbeta, mxbeta] = min_beta_ocrd(data_s.pdata, data_s.data, params_s.bregman_fn)

beta_all = mnbeta:(mxbeta-mnbeta)/100:mxbeta;
params_s.thresh = 1e-2;
params_s.epochs = 1;

params_s.max_rounds = 50;
verbose_s.level = 0;

% cool the system    
ind=1;
for beta=beta_all,
    data_s.beta = beta;
    res_s = ocrd_cluster(data_s, params_s, verbose_s);
    cluster_id(:,ind) = (res_s.q == 1);
    res_all{ind}=res_s; ind=ind+1;
    
    params_s.q = res_s.q;
end

d = data;
data.x=data_s.data;

mov=moviein(length(beta_all));
for ind=1:length(res_all),
    clf;hold on;axis tight;
    plot(data.x(1,:),data.x(2,:),'k.','MarkerSize',8)
    i = find(res_all{ind}.q == 1);
    plot(data.x(1,i),data.x(2,i),'ro','MarkerSize',8);
    title(sprintf('beta=%5.2f',(beta_all(ind)-mnbeta)/(mxbeta-mnbeta)));
    axis tight;drawnow;
    mov(:,ind) = getframe;
end


movie(mov);
